# -*- coding: utf-8 -*-
import pymysql
import time,os,json

# User-defined parameters
db_name = os.getenv("DB_NAME")
if db_name is None:
    db_name = "mysql_db"

mysql_ip = os.getenv("MYSQL_IP")
if mysql_ip is None:
    mysql_ip = "172.17.0.1" # Use docker0 IP as default

table_max_entries = 10000 # Maximum entries per table
table_clean_count = 4000  # Entries to be clean data reaches the table_max_entries

os.getenv('ENV_PORT')

connect = pymysql.connect(host=mysql_ip,user="root",password="123456", charset="utf8")
cursor = connect.cursor()

def db_init(table_name):
  # create mysql database
  sql2 = "CREATE DATABASE IF NOT EXISTS " + db_name 
  cursor.execute(sql2)
  
  sql3 = "USE " + db_name
  cursor.execute(sql3)
  
  sql = "CREATE TABLE IF NOT EXISTS "+table_name+"(PROPERTY CHAR(32) NOT NULL, VALUE CHAR(32) NOT NULL, TIME TIMESTAMP not NULL DEFAULT CURRENT_TIMESTAMP)"
  cursor.execute(sql)

def handler(event, context):
  print("-- Receive new event: ", event)
  try:
    edict = json.loads(event)
    topic = edict['topic']
    tlist = topic.split('/')
    if tlist[1] == 'sys':
      productKey = tlist[2]
      deviceName = tlist[3]
      tableName = productKey+'_'+deviceName
      print("-- Table Name : "+tableName)
      db_init(tableName)
    else:
      print("-- [Warn] Event topic should start with /sys/. Ignore!")
      return 'OK'
     
    cursor.execute("SELECT count(*) FROM "+tableName)
    tableItemNum = cursor.fetchone()[0]
    print("-- Table {} total items = {}".format(tableName,tableItemNum))
 
    if tableItemNum>table_max_entries:
        print("-- Clean Table {} oldest records.".format(tableName))
        cursor.execute("DELETE FROM " + tableName + " limit "+ str(table_clean_count))

    payload = json.loads(edict['payload'])
    for key,value in payload.items():
      # You could add the data filetering logic here, before saving to DB.
      print("-- Save "+str(key)+':'+str(value['value']) +" to table "+ tableName)
      cursor.execute("INSERT INTO "+tableName+"(PROPERTY,VALUE) VALUES (%s,%s)", (str(key),str(value['value'])))
    
    connect.commit()
  except Exception as e:
    print("-- [Warn] Event parse failed. Ignore! ", e)

  return 'OK'

